@@ -44,9 +44,7 @@ This is open-source software, released under the MIT Software License:
 http://www.opensource.org/licenses/mit-license.php
 
 """
-from __future__ import print_function
 
-from builtins import object
 __version__ = "2.0"
 
 __all__ = [
@@ -80,7 +78,7 @@ import traceback
 import weakref
 
 
-class method(object):
+class method:
     sequential = "sequential"
     forked = "forked"
     threaded = "threaded"
@@ -96,7 +94,7 @@ class SchedulerNotRunning(Exception):
     pass
 
 
-class Scheduler(object):
+class Scheduler:
     """The Scheduler itself."""
 
     def __init__(self):
@@ -296,7 +294,7 @@ class Scheduler(object):
                 self.sched.run()
             except SchedulerNotRunning:
                 self._clearschedqueue()
-            except Exception as x:
+            except Exception, x:
                 self.log.error(
                     "ERROR DURING SCHEDULER EXECUTION %s \n %s",
                     x,
@@ -321,7 +319,7 @@ class Task(object):
         """Execute the task action in the scheduler's thread."""
         try:
             self.execute()
-        except Exception as x:
+        except Exception, x:
             self.handle_exception(x)
         self.reschedule(schedulerref())
 
@@ -374,7 +372,7 @@ class IntervalTask(Task):
             scheduler.schedule_task(self, self.interval)
 
 
-class DayTaskRescheduler(object):
+class DayTaskRescheduler:
     """A mixin class that contains the reschedule logic for the DayTasks."""
 
     def __init__(self, timeonday):
@@ -488,7 +486,7 @@ try:
             """Release the lock on the thread's task queue."""
             self._lock.release()
 
-    class ThreadedTaskMixin(object):
+    class ThreadedTaskMixin:
         """A mixin class to make a Task execute in a separate thread."""
 
         def __call__(self, schedulerref):
@@ -501,7 +499,7 @@ try:
             # do the execute() call and exception handling here.
             try:
                 self.execute()
-            except Exception as x:
+            except Exception, x:
                 self.handle_exception(x)
 
     class ThreadedIntervalTask(ThreadedTaskMixin, IntervalTask):
@@ -563,7 +561,7 @@ if hasattr(os, "fork"):
         def signalhandler(self, sig, stack):
             Scheduler.stop(self)
 
-    class ForkedTaskMixin(object):
+    class ForkedTaskMixin:
         """A mixin class to make a Task execute in a separate process."""
 
         def __call__(self, schedulerref):
@@ -573,7 +571,7 @@ if hasattr(os, "fork"):
                 # we are the child
                 try:
                     self.execute()
-                except Exception as x:
+                except Exception, x:
                     self.handle_exception(x)
                 os._exit(0)
             else:
@@ -605,9 +603,9 @@ if hasattr(os, "fork"):
 
 if __name__ == "__main__":
     def testaction(arg):
-        print((">>>TASK", arg, "sleeping 3 seconds"))
+        print (">>>TASK", arg, "sleeping 3 seconds")
         time.sleep(3)
-        print(("<<<END_TASK", arg))
+        print ("<<<END_TASK", arg)
 
     s = ThreadedScheduler()
     s.add_interval_task(testaction,
