@@ -1,17 +1,12 @@
-from __future__ import print_function
-from future import standard_library
-standard_library.install_aliases()
-from builtins import str
 import inspect
-import http.client
+import httplib
 import json
 import logging
 import os
 import sys
 from _ssl import SSLError
 from json import loads
-from urllib.request import Request, urlopen
-from urllib.error import HTTPError, URLError
+from urllib2 import Request, urlopen, HTTPError, URLError
 import yaml
 
 sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
@@ -166,7 +161,7 @@ def safe_post_url(url, message, token=None, log=logging.getLogger('spotinst-agen
         log.error("Unable to reach the server for POST request. [reason: {}]".format(e.reason))
     except SSLError as e:
         log.error("Connection to API timed out, retry in next iteration : {}".format(str(e)))
-    except http.client.BadStatusLine as e:
+    except httplib.BadStatusLine as e:
         log.error("Bad status line. The URL is most likely wrong.")
     except Exception as e:
         log.error("There was an error of POST url. Exceptions: " + str(sys.exc_info()[0]))
@@ -210,7 +205,7 @@ def parse_yml(yml, log=logging.getLogger('spotinst-agent')):
     # Initialize Config
     with open(yml) as f:
         try:
-            return yaml.load(f, yaml.FullLoader)
+            return yaml.load(f)
         except Exception as e:
             log.error("Can't parse yml file {}. Exception {}".format(yml, e))
             raise e
